==> traintrain_0.4.3-1.tar.gz: traintrain-0.4.3/src/opt/traintrain/view/SettingsDlg.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys, sqlite3, os
from utils.DebugLog import DebugLog
from utils.Config import TrainTrainConf
from PyQt4 import QtCore, QtGui
from PyQt4.QtCore import Qt
from PyQt4.QtGui import QApplication

class SettingsDlg(QtGui.QDialog ):
   def __init__(self):
      QtGui.QDialog.__init__(self)

      self.conf = TrainTrainConf()

      self.CreateLayouts()
      self.setModal(True)
      self.setWindowTitle(u'Paramètres')

   def CreateLayouts(self):
      hLayout = QtGui.QHBoxLayout()
      labelnb = QtGui.QLabel('Nombre de trains par trajet')
      self.editnb = QtGui.QLineEdit()
      self.editnb.setText('%d'%self.conf.nbTrains())
      hLayout.addWidget(labelnb)
      hLayout.addWidget(self.editnb)

      hLayout2 = QtGui.QHBoxLayout()
      labelra = QtGui.QLabel(u'Rafraîchissement auto')
      self.refresh = QtGui.QComboBox()
      rlist = QtCore.QStringList()
      rlist << '15 s' << '30 s' << '1 min' << '5 min'
      self.refresh.addItems(rlist)
      idx = rlist.indexOf(self.conf.refreshRate())
      self.refresh.setCurrentIndex(idx)
      hLayout2.addWidget(labelra)
      hLayout2.addWidget(self.refresh)

      vbox = QtGui.QVBoxLayout()
      vbox.addLayout(hLayout)
      vbox.addLayout(hLayout2)

      hLayout3 = QtGui.QHBoxLayout()
      buttons = QtGui.QDialogButtonBox()
      buttons.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
      self.connect(buttons, QtCore.SIGNAL("accepted()"), self.OnOK)
      self.connect(buttons, QtCore.SIGNAL("rejected()"), self.OnCancel)

      hLayout3.addWidget(buttons)
      vbox.addLayout(hLayout3)

      self.setLayout(vbox)

   def OnOK(self):
      self.conf.SetNbTrains( self.editnb.text() )
      self.conf.SetRefreshRate( self.refresh.currentText() )
      self.conf.WriteConfig()
      self.accept()

   def OnCancel(self):
      self.reject()

==> traintrain_0.6.2-1.tar.gz: traintrain-0.6.2/src/opt/traintrain/view/SettingsDlg.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys, sqlite3, os
from utils.DebugLog import DebugLog
from utils.Config import TrainTrainConf
from PyQt4 import QtCore, QtGui
from PyQt4.QtCore import Qt
from PyQt4.QtGui import QApplication

class SettingsDlg(QtGui.QDialog ):
   def __init__(self):
      QtGui.QDialog.__init__(self)

      self.conf = TrainTrainConf()

      self.CreateLayouts()
      self.setModal(True)
      self.setWindowTitle(u'Paramètres')

   def CreateLayouts(self):
      hLayout = QtGui.QHBoxLayout()
      labelnb = QtGui.QLabel('Nombre max de trains par trajet')
      self.editnb = QtGui.QLineEdit()
      self.editnb.setText('%d'%self.conf.nbTrains())
      hLayout.addWidget(labelnb)
      hLayout.addWidget(self.editnb)

      hLayout2 = QtGui.QHBoxLayout()
      labelra = QtGui.QLabel(u'Rafraîchissement auto')
      self.refresh = QtGui.QComboBox()
      rlist = QtCore.QStringList()
      rlist << '15 s' << '30 s' << '1 min' << '5 min'
      self.refresh.addItems(rlist)
      idx = rlist.indexOf(self.conf.refreshRate())
      self.refresh.setCurrentIndex(idx)
      hLayout2.addWidget(labelra)
      hLayout2.addWidget(self.refresh)

      vbox = QtGui.QVBoxLayout()
      vbox.addLayout(hLayout)
      vbox.addLayout(hLayout2)

      hLayout3 = QtGui.QHBoxLayout()
      buttons = QtGui.QDialogButtonBox()
      buttons.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
      self.connect(buttons, QtCore.SIGNAL("accepted()"), self.OnOK)
      self.connect(buttons, QtCore.SIGNAL("rejected()"), self.OnCancel)

      hLayout3.addWidget(buttons)
      vbox.addLayout(hLayout3)

      self.setLayout(vbox)

   def OnOK(self):
      self.conf.SetNbTrains( self.editnb.text() )
      self.conf.SetRefreshRate( self.refresh.currentText() )
      self.conf.WriteConfig()
      self.accept()

   def OnCancel(self):
      self.reject()
